Documentation
¶
Overview ¶
Package hiprus provides a Hipchat hook for the logrus loggin package.
Index ¶
Constants ¶
const (
VERSION = "1.0.2"
)
Variables ¶
var AllLevels = []logrus.Level{ logrus.DebugLevel, logrus.InfoLevel, logrus.WarnLevel, logrus.ErrorLevel, logrus.FatalLevel, logrus.PanicLevel, }
Functions ¶
Types ¶
type HiprusHook ¶
type HiprusHook struct {
// Messages with a log level not contained in this array
// will not be dispatched. If nil, all messages will be dispatched.
AcceptedLevels []logrus.Level
AuthToken string
RoomName string
// If empty, "Hiprus" will be used.
Username string
// contains filtered or unexported fields
}
HiprusHook is a logrus Hook for dispatching messages to the specified channel on Hipchat.
func (*HiprusHook) Levels ¶
func (hh *HiprusHook) Levels() []logrus.Level
Click to show internal directories.
Click to hide internal directories.